@@ -32,18 +32,15 @@
 class QPushButton;
 class CalendarView;
 
-namespace Ui
-{
+namespace Ui {
 class SearchDialog;
 }
 
-namespace EventViews
-{
+namespace EventViews {
 class ListView;
 }
 
-namespace KCalCore
-{
+namespace KCalCore {
 class Incidence;
 }
 
@@ -52,7 +49,7 @@ class SearchDialog : public QDialog
     Q_OBJECT
 public:
     explicit SearchDialog(CalendarView *calendarview);
-    virtual ~SearchDialog();
+    ~SearchDialog() override;
 
     void updateView();
 
