@@ -40,7 +40,8 @@ KOrganizerApp::KOrganizerApp(int &argc, char **argv[])
     : KontactInterface::PimUniqueApplication(argc, argv)
 {
     QString prodId = QStringLiteral("-//K Desktop Environment//NONSGML KOrganizer %1//EN");
-    KCalCore::CalFormat::setApplication(QStringLiteral("KOrganizer"), prodId.arg(QStringLiteral(KORGANIZER_VERSION)));
+    KCalCore::CalFormat::setApplication(QStringLiteral("KOrganizer"),
+                                        prodId.arg(QStringLiteral(KORGANIZER_VERSION)));
 }
 
 KOrganizerApp::~KOrganizerApp()
