@@ -32,13 +32,11 @@
 
 class QPushButton;
 
-namespace Ui
-{
+namespace Ui {
 class KOGroupwarePrefsPage;
 }
 
-namespace Akonadi
-{
+namespace Akonadi {
 class CollectionComboBox;
 }
 
@@ -80,12 +78,12 @@ protected Q_SLOTS:
     void updateResourceColor();
 
 private:
-    KComboBox     *mCategoryCombo = nullptr;
-    KColorButton  *mCategoryButton = nullptr;
+    KComboBox *mCategoryCombo = nullptr;
+    KColorButton *mCategoryButton = nullptr;
     QHash<QString, QColor> mCategoryDict;
 
     Akonadi::CollectionComboBox *mResourceCombo = nullptr;
-    KColorButton  *mResourceButton = nullptr;
+    KColorButton *mResourceButton = nullptr;
     QHash<QString, QColor> mResourceDict;
 };
 
@@ -122,6 +120,7 @@ class KCM_KORGANIZER_EXPORT KOPrefsDialogPlugins : public KPIM::KPrefsModule
     Q_OBJECT
 public:
     KOPrefsDialogPlugins(QWidget *parent);
+    ~KOPrefsDialogPlugins();
 
 protected Q_SLOTS:
     void usrWriteConfig() override;
@@ -137,9 +136,10 @@ private:
     QPushButton *mConfigureButton = nullptr;
     QGroupBox *mPositioningGroupBox = nullptr;
 
-
     QRadioButton *mPositionAgendaTop = nullptr;
     QRadioButton *mPositionAgendaBottom = nullptr;
+    QTreeWidgetItem *mDecorations = nullptr;
+    QTreeWidgetItem *mOthers = nullptr;
     QSet<QString> mDecorationsAtMonthViewTop;
     QSet<QString> mDecorationsAtAgendaViewTop;
     QSet<QString> mDecorationsAtAgendaViewBottom;
